package system
import "github.com/dotcloud/docker/api/server/router/system"
Index ¶
- func NewRouter(b Backend, c ClusterBackend, builder BuildBackend, features func() map[string]bool) router.Router
- type Backend
- type BuildBackend
- type ClusterBackend
- type StatusProvider
Functions ¶
func NewRouter ¶
func NewRouter(b Backend, c ClusterBackend, builder BuildBackend, features func() map[string]bool) router.Router
NewRouter initializes a new system router
Types ¶
type Backend ¶
type Backend interface {
SystemInfo(context.Context) (*system.Info, error)
SystemVersion(context.Context) (types.Version, error)
SystemDiskUsage(ctx context.Context, opts backend.DiskUsageOptions) (*backend.DiskUsage, error)
SubscribeToEvents(since, until time.Time, ef filters.Args) ([]events.Message, chan interface{})
UnsubscribeFromEvents(chan interface{})
AuthenticateToRegistry(ctx context.Context, authConfig *registry.AuthConfig) (string, string, error)
}
Backend is the methods that need to be implemented to provide system specific functionality.
type BuildBackend ¶
type BuildBackend interface {
DiskUsage(context.Context) ([]*build.CacheRecord, error)
}
BuildBackend provides build specific system information.
type ClusterBackend ¶
ClusterBackend is all the methods that need to be implemented to provide cluster system specific functionality.
type StatusProvider ¶
type StatusProvider interface {
Status() string
}
StatusProvider provides methods to get the swarm status of the current node.
Source Files ¶
backend.go info_response.go system.go system_routes.go
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 23 packages
- Last checked
- 4 months ago –
Tools for package owners.