package auxprogress
import "github.com/dotcloud/docker/api/types/auxprogress"
Index ¶
Types ¶
type ContentMissing ¶
type ContentMissing struct {
ContentMissing bool `json:"contentMissing"` // Always true
// Desc is the descriptor of the root object that was attempted to be pushed.
Desc ocispec.Descriptor `json:"desc"`
}
ContentMissing is a note that is sent when push fails because the content is missing.
type ManifestPushedInsteadOfIndex ¶
type ManifestPushedInsteadOfIndex struct {
ManifestPushedInsteadOfIndex bool `json:"manifestPushedInsteadOfIndex"` // Always true
// OriginalIndex is the descriptor of the original image index.
OriginalIndex ocispec.Descriptor `json:"originalIndex"`
// SelectedManifest is the descriptor of the manifest that was pushed instead.
SelectedManifest ocispec.Descriptor `json:"selectedManifest"`
}
ManifestPushedInsteadOfIndex is a note that is sent when a manifest is pushed instead of an index. It is sent when the pushed image is an multi-platform index, but the whole index couldn't be pushed.
Source Files ¶
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 1 packages
- Last checked
- 1 hour ago –
Tools for package owners.