package runtime

import "github.com/dotcloud/docker/api/types/swarm/runtime"

Index

Variables

var (
	ErrInvalidLengthPlugin        = fmt.Errorf("proto: negative length found during unmarshaling") // Deprecated: this error was only used internally and is no longer used.
	ErrIntOverflowPlugin          = fmt.Errorf("proto: integer overflow")                          // Deprecated: this error was only used internally and is no longer used.
	ErrUnexpectedEndOfGroupPlugin = fmt.Errorf("proto: unexpected end of group")                   // Deprecated: this error was only used internally and is no longer used.
)

Types

type PluginPrivilege

type PluginPrivilege struct {
	Name        string   `json:"name,omitempty"`
	Description string   `json:"description,omitempty"`
	Value       []string `json:"value,omitempty"`
}

PluginPrivilege describes a permission the user has to accept upon installing a plugin.

type PluginSpec

type PluginSpec struct {
	Name       string             `json:"name,omitempty"`
	Remote     string             `json:"remote,omitempty"`
	Privileges []*PluginPrivilege `json:"privileges,omitempty"`
	Disabled   bool               `json:"disabled,omitempty"`
	Env        []string           `json:"env,omitempty"`
}

PluginSpec defines the base payload which clients can specify for creating a service with the plugin runtime.

Source Files

runtime.go

Version
v28.5.2+incompatible (latest)
Published
Nov 5, 2025
Platform
linux/amd64
Imports
1 packages
Last checked
4 months ago

Tools for package owners.