package builder
import "github.com/dotcloud/docker/builder"
Package builder defines interfaces for any Docker builder to implement.
Historically, only server-side Dockerfile interpreters existed. This package allows for other implementations of Docker builders.
Index ¶
- Constants
- type Backend
- type ExecBackend
- type Image
- type ImageBackend
- type ImageCache
- type ImageCacheBuilder
- type ROLayer
- type RWLayer
- type Result
- type Source
Constants ¶
const ( // DefaultDockerfileName is the Default filename with Docker commands, read by docker build DefaultDockerfileName = "Dockerfile" )
Types ¶
type Backend ¶
type Backend interface {
ImageBackend
ExecBackend
// CommitBuildStep creates a new Docker image from the config generated by
// a build step.
CommitBuildStep(context.Context, backend.CommitConfig) (image.ID, error)
// ContainerCreateWorkdir creates the workdir
ContainerCreateWorkdir(containerID string) error
CreateImage(ctx context.Context, config []byte, parent string, contentStoreDigest digest.Digest) (Image, error)
ImageCacheBuilder
}
Backend abstracts calls to a Docker Daemon.
type ExecBackend ¶
type ExecBackend interface {
// ContainerAttachRaw attaches to container.
ContainerAttachRaw(cID string, stdin io.ReadCloser, stdout, stderr io.Writer, stream bool, attached chan struct{}) error
// ContainerCreateIgnoreImagesArgsEscaped creates a new Docker container and returns potential warnings
ContainerCreateIgnoreImagesArgsEscaped(ctx context.Context, config backend.ContainerCreateConfig) (container.CreateResponse, error)
// ContainerRm removes a container specified by `id`.
ContainerRm(name string, config *backend.ContainerRmConfig) error
// ContainerStart starts a new container
ContainerStart(ctx context.Context, containerID string, checkpoint string, checkpointDir string) error
// ContainerWait stops processing until the given container is stopped.
ContainerWait(ctx context.Context, name string, condition container.WaitCondition) (<-chan container.StateStatus, error)
}
ExecBackend contains the interface methods required for executing containers
type Image ¶
type Image interface {
ImageID() string
RunConfig() *container.Config
MarshalJSON() ([]byte, error)
OperatingSystem() string
}
Image represents a Docker image used by the builder.
type ImageBackend ¶
type ImageBackend interface {
GetImageAndReleasableLayer(ctx context.Context, refOrID string, opts backend.GetImageAndLayerOptions) (Image, ROLayer, error)
}
ImageBackend are the interface methods required from an image component
type ImageCache ¶
type ImageCache interface {
// GetCache returns a reference to a cached image whose parent equals `parent`
// and runconfig equals `cfg`. A cache miss is expected to return an empty ID and a nil error.
GetCache(parentID string, cfg *container.Config, platform ocispec.Platform) (imageID string, err error)
}
ImageCache abstracts an image cache. (parent image, child runconfig) -> child image
type ImageCacheBuilder ¶
type ImageCacheBuilder interface {
// MakeImageCache creates a stateful image cache.
MakeImageCache(ctx context.Context, cacheFrom []string) (ImageCache, error)
}
ImageCacheBuilder represents a generator for stateful image cache.
type ROLayer ¶
type ROLayer interface {
Release() error
NewRWLayer() (RWLayer, error)
DiffID() layer.DiffID
ContentStoreDigest() digest.Digest
}
ROLayer is a reference to image rootfs layer
type RWLayer ¶
RWLayer is active layer that can be read/modified
type Result ¶
Result is the output produced by a Builder
type Source ¶
type Source interface {
// Root returns root path for accessing source
Root() string
// Close allows to signal that the filesystem tree won't be used anymore.
// For Context implementations using a temporary directory, it is recommended to
// delete the temporary directory in Close().
Close() error
// Hash returns a checksum for a file
Hash(path string) (string, error)
}
Source defines a location that can be used as a source for the ADD/COPY instructions in the builder.
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| builder/builder-next | |
| builder/builder-next/adapters | |
| builder/builder-next/adapters/containerimage | |
| builder/builder-next/adapters/localinlinecache | |
| builder/builder-next/adapters/snapshot | |
| builder/builder-next/exporter | |
| builder/builder-next/exporter/mobyexporter | |
| builder/builder-next/exporter/overrides | |
| builder/builder-next/imagerefchecker | |
| builder/builder-next/worker | |
| builder/builder-next/worker/label | |
| builder/dockerfile | Package dockerfile is the evaluation step in the Dockerfile parse/evaluate pipeline. |
| builder/remotecontext | |
| builder/remotecontext/git | |
| builder/remotecontext/urlutil | Package urlutil provides helper function to check if a given build-context location should be considered a URL or a remote Git repository. |
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 8 packages
- Last checked
- 4 months ago –
Tools for package owners.