package imagerefchecker
import "github.com/dotcloud/docker/builder/builder-next/imagerefchecker"
Index ¶
Functions ¶
func New ¶
func New(opt Opt) cache.ExternalRefCheckerFunc
New creates new image reference checker that can be used to see if a reference is being used by any of the images in the image store
Types ¶
type LayerGetter ¶
LayerGetter abstracts away the snapshotter
type Opt ¶
type Opt struct {
LayerGetter LayerGetter
ImageStore image.Store
}
Opt represents the options needed to create a refchecker
Source Files ¶
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 4 months ago –
Tools for package owners.