package journald
import "github.com/dotcloud/docker/daemon/logger/journald"
Package journald provides the log driver for forwarding server logs to endpoints that receive the systemd format.
Index ¶
Functions ¶
func New ¶
New creates a journald logger using the configuration passed in on the context.
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| daemon/logger/journald/internal |
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 9 packages
- Last checked
- 4 months ago –
Tools for package owners.