package snapshotter
import "github.com/dotcloud/docker/daemon/snapshotter"
Index ¶
- func NewMounter(home string, snapshotter string, idMap user.IdentityMapping) *refCountMounter
- type Mounter
Functions ¶
func NewMounter ¶
func NewMounter(home string, snapshotter string, idMap user.IdentityMapping) *refCountMounter
NewMounter creates a new mounter for the provided snapshotter
Types ¶
type Mounter ¶
type Mounter interface {
// Mount mounts the rootfs for a container and returns the mount point
Mount(mounts []mount.Mount, containerID string) (string, error)
// Unmount unmounts the container rootfs
Unmount(target string) error
// Mounted returns a target mountpoint if it's already mounted
Mounted(containerID string) (string, error)
}
Mounter handles mounting/unmounting things coming in from a snapshotter with optional reference counting if needed by the filesystem
Source Files ¶
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 4 months ago –
Tools for package owners.