package overlay
import "github.com/dotcloud/docker/libnetwork/drivers/overlay"
Index ¶
- Constants
- Variables
- func Register(r driverapi.Registerer, config map[string]interface{}) error
- type PeerRecord
- func (*PeerRecord) Descriptor() ([]byte, []int)
- func (m *PeerRecord) GetEndpointIP() string
- func (m *PeerRecord) GetEndpointMAC() string
- func (m *PeerRecord) GetTunnelEndpointIP() string
- func (this *PeerRecord) GoString() string
- func (m *PeerRecord) Marshal() (dAtA []byte, err error)
- func (m *PeerRecord) MarshalTo(dAtA []byte) (int, error)
- func (m *PeerRecord) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*PeerRecord) ProtoMessage()
- func (m *PeerRecord) Reset()
- func (m *PeerRecord) Size() (n int)
- func (this *PeerRecord) String() string
- func (m *PeerRecord) Unmarshal(dAtA []byte) error
- func (m *PeerRecord) XXX_DiscardUnknown()
- func (m *PeerRecord) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *PeerRecord) XXX_Merge(src proto.Message)
- func (m *PeerRecord) XXX_Size() int
- func (m *PeerRecord) XXX_Unmarshal(b []byte) error
Constants ¶
const (
NetworkType = "overlay"
)
Variables ¶
var ( ErrInvalidLengthOverlay = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowOverlay = fmt.Errorf("proto: integer overflow") ErrUnexpectedEndOfGroupOverlay = fmt.Errorf("proto: unexpected end of group") )
Functions ¶
func Register ¶
func Register(r driverapi.Registerer, config map[string]interface{}) error
Register registers a new instance of the overlay driver.
Types ¶
type PeerRecord ¶
type PeerRecord struct {
// Endpoint IP is the IP of the container attachment on the
// given overlay network.
EndpointIP string `protobuf:"bytes,1,opt,name=endpoint_ip,json=endpointIp,proto3" json:"endpoint_ip,omitempty"`
// Endpoint MAC is the mac address of the container attachment
// on the given overlay network.
EndpointMAC string `protobuf:"bytes,2,opt,name=endpoint_mac,json=endpointMac,proto3" json:"endpoint_mac,omitempty"`
// Tunnel Endpoint IP defines the host IP for the host in
// which this container is running and can be reached by
// building a tunnel to that host IP.
TunnelEndpointIP string `protobuf:"bytes,3,opt,name=tunnel_endpoint_ip,json=tunnelEndpointIp,proto3" json:"tunnel_endpoint_ip,omitempty"`
}
PeerRecord defines the information corresponding to a peer container in the overlay network.
func (*PeerRecord) Descriptor ¶
func (*PeerRecord) Descriptor() ([]byte, []int)
func (*PeerRecord) GetEndpointIP ¶
func (m *PeerRecord) GetEndpointIP() string
func (*PeerRecord) GetEndpointMAC ¶
func (m *PeerRecord) GetEndpointMAC() string
func (*PeerRecord) GetTunnelEndpointIP ¶
func (m *PeerRecord) GetTunnelEndpointIP() string
func (*PeerRecord) GoString ¶
func (this *PeerRecord) GoString() string
func (*PeerRecord) Marshal ¶
func (m *PeerRecord) Marshal() (dAtA []byte, err error)
func (*PeerRecord) MarshalTo ¶
func (m *PeerRecord) MarshalTo(dAtA []byte) (int, error)
func (*PeerRecord) MarshalToSizedBuffer ¶
func (m *PeerRecord) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*PeerRecord) ProtoMessage ¶
func (*PeerRecord) ProtoMessage()
func (*PeerRecord) Reset ¶
func (m *PeerRecord) Reset()
func (*PeerRecord) Size ¶
func (m *PeerRecord) Size() (n int)
func (*PeerRecord) String ¶
func (this *PeerRecord) String() string
func (*PeerRecord) Unmarshal ¶
func (m *PeerRecord) Unmarshal(dAtA []byte) error
func (*PeerRecord) XXX_DiscardUnknown ¶
func (m *PeerRecord) XXX_DiscardUnknown()
func (*PeerRecord) XXX_Marshal ¶
func (m *PeerRecord) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*PeerRecord) XXX_Merge ¶
func (m *PeerRecord) XXX_Merge(src proto.Message)
func (*PeerRecord) XXX_Size ¶
func (m *PeerRecord) XXX_Size() int
func (*PeerRecord) XXX_Unmarshal ¶
func (m *PeerRecord) XXX_Unmarshal(b []byte) error
Source Files ¶
bpf.go encryption.go joinleave.go ostweaks_linux.go ov_endpoint.go ov_network.go ov_utils.go overlay.go overlay.pb.go peerdb.go
Directories ¶
| Path | Synopsis |
|---|---|
| libnetwork/drivers/overlay/overlayutils | Package overlayutils provides utility functions for overlay networks |
| libnetwork/drivers/overlay/ovmanager |
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 43 packages
- Last checked
- 2 hours ago –
Tools for package owners.