package ipams
import "github.com/dotcloud/docker/libnetwork/ipams"
Index ¶
Functions ¶
func Register ¶
func Register(r ipamapi.Registerer, pg plugingetter.PluginGetter, lAddrPools, gAddrPools []*ipamutils.NetworkToSplit) error
Register registers all the builtin drivers (ie. default, windowsipam, null and remote). 'pg' is nil here in case of non-managed plugins which Windows is using.
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| libnetwork/ipams/defaultipam | |
| libnetwork/ipams/null | Package null implements the null ipam driver. |
| libnetwork/ipams/remote | |
| libnetwork/ipams/remote/api | Package api defines the data structure to be used in the request/response messages between libnetwork and the remote ipam plugin |
| libnetwork/ipams/windowsipam |
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 7 packages
- Last checked
- 4 months ago –
Tools for package owners.