package api
import "github.com/dotcloud/docker/libnetwork/ipams/remote/api"
Package api defines the data structure to be used in the request/response messages between libnetwork and the remote ipam plugin
Index ¶
- type GetAddressSpacesResponse
- type GetCapabilityResponse
- type ReleaseAddressRequest
- type ReleaseAddressResponse
- type ReleasePoolRequest
- type ReleasePoolResponse
- type RequestAddressRequest
- type RequestAddressResponse
- type RequestPoolRequest
- type RequestPoolResponse
- type Response
Types ¶
type GetAddressSpacesResponse ¶
type GetAddressSpacesResponse struct {
Response
LocalDefaultAddressSpace string
GlobalDefaultAddressSpace string
}
GetAddressSpacesResponse is the response to the “get default address spaces“ request message
type GetCapabilityResponse ¶
GetCapabilityResponse is the response of GetCapability request
func (GetCapabilityResponse) ToCapability ¶
func (capRes GetCapabilityResponse) ToCapability() *ipamapi.Capability
ToCapability converts the capability response into the internal ipam driver capability structure
type ReleaseAddressRequest ¶
ReleaseAddressRequest represents the expected data in a “release address“ request message
type ReleaseAddressResponse ¶
type ReleaseAddressResponse struct {
Response
}
ReleaseAddressResponse represents the response message to a “release address“ request
type ReleasePoolRequest ¶
type ReleasePoolRequest struct {
PoolID string
}
ReleasePoolRequest represents the expected data in a “release address pool“ request message
type ReleasePoolResponse ¶
type ReleasePoolResponse struct {
Response
}
ReleasePoolResponse represents the response message to a “release address pool“ request
type RequestAddressRequest ¶
RequestAddressRequest represents the expected data in a “request address“ request message
type RequestAddressResponse ¶
type RequestAddressResponse struct {
Response
Address string // in CIDR format
Data map[string]string
}
RequestAddressResponse represents the expected data in the response message to a “request address“ request
type RequestPoolRequest ¶
type RequestPoolRequest struct {
AddressSpace string
Pool string
SubPool string
Options map[string]string
V6 bool
}
RequestPoolRequest represents the expected data in a “request address pool“ request message
type RequestPoolResponse ¶
type RequestPoolResponse struct {
Response
PoolID string
Pool string // CIDR format
Data map[string]string
}
RequestPoolResponse represents the response message to a “request address pool“ request
type Response ¶
type Response struct {
Error string
}
Response is the basic response structure used in all responses
func (*Response) GetError ¶
GetError returns the error from the response, if any.
func (*Response) IsSuccess ¶
IsSuccess returns whether the plugin response is successful
Source Files ¶
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 1 packages
- Last checked
- 4 months ago –
Tools for package owners.