package reference
import "github.com/dotcloud/docker/reference"
Index ¶
Variables ¶
var ErrDoesNotExist notFoundError = "reference does not exist"
ErrDoesNotExist is returned if a reference is not found in the store.
Types ¶
type Association ¶
An Association is a tuple associating a reference with an image ID.
type Store ¶
type Store interface {
References(id digest.Digest) []reference.Named
ReferencesByName(ref reference.Named) []Association
AddTag(ref reference.Named, id digest.Digest, force bool) error
AddDigest(ref reference.Canonical, id digest.Digest, force bool) error
Delete(ref reference.Named) (bool, error)
Get(ref reference.Named) (digest.Digest, error)
}
Store provides the set of methods which can operate on a reference store.
func NewReferenceStore ¶
NewReferenceStore creates a new reference store, tied to a file path where the set of references are serialized in JSON format.
Source Files ¶
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 4 months ago –
Tools for package owners.