package apparmor
import "github.com/dotcloud/docker/profiles/apparmor"
Index ¶
Functions ¶
func InstallDefault ¶
InstallDefault generates a default profile in a temp directory determined by os.TempDir(), then loads the profile into the kernel using 'apparmor_parser'.
Deprecated: use apparmor.InstallDefault.
func IsLoaded ¶
IsLoaded checks if a profile with the given name has been loaded into the kernel.
Deprecated: use apparmor.IsLoaded.
Source Files ¶
- Version
- v28.5.2+incompatible (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Imports
- 1 packages
- Last checked
- 4 months ago –
Tools for package owners.